#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 idris
version:              1.3.3
visibility:           public
id:                   idris-1.3.3-IUYfrh8doFfLjFwBEieOr1
key:                  idris-1.3.3-IUYfrh8doFfLjFwBEieOr1
license:              BSD-3-Clause
maintainer:           Niklas Larsson <niklas@mm.st>
author:               Edwin Brady
stability:            Beta
homepage:             https://www.idris-lang.org/
synopsis:             Functional Programming Language with Dependent Types
description:
    Idris is a general purpose language with full dependent types.
    It is compiled, with eager evaluation.
    Dependent types allow types to be predicated on values,
    meaning that some aspects of a program'\''s behaviour can be
    specified precisely in the type. The language is closely
    related to Epigram and Agda. There is a tutorial at
    <https://www.idris-lang.org/documentation>.
    Features include:

    * Full, first class, dependent types with dependent pattern matching

    * where clauses, with rule, case expressions,
    pattern matching let and lambda bindings

    * Interfaces (similar to type classes), monad comprehensions

    * do notation, idiom brackets, syntactic conveniences for lists,
    tuples, dependent pairs

    * Totality checking

    * Coinductive types

    * Indentation significant syntax, extensible syntax

    * Cumulative universes

    * Simple foreign function interface (to C)

    * Hugs style interactive environment

category:             Compilers/Interpreters, Dependent Types
abi:                  0acc713b26983190eeb13c6b1d3ec9d2
exposed:              True
exposed-modules:
    IRTS.Bytecode IRTS.CodegenC IRTS.CodegenCommon
    IRTS.CodegenJavaScript IRTS.Compiler IRTS.Defunctionalise
    IRTS.DumpBC IRTS.Exports IRTS.Inliner IRTS.JavaScript.AST
    IRTS.JavaScript.Codegen IRTS.JavaScript.LangTransforms
    IRTS.JavaScript.Name IRTS.JavaScript.PrimOp
    IRTS.JavaScript.Specialize IRTS.Lang IRTS.LangOpts IRTS.Portable
    IRTS.Simplified IRTS.System Idris.ASTUtils Idris.AbsSyntax
    Idris.AbsSyntaxTree Idris.Apropos Idris.CaseSplit Idris.Chaser
    Idris.CmdOptions Idris.Colours Idris.Completion Idris.Core.Binary
    Idris.Core.CaseTree Idris.Core.Constraints Idris.Core.DeepSeq
    Idris.Core.Elaborate Idris.Core.Evaluate Idris.Core.Execute
    Idris.Core.ProofState Idris.Core.ProofTerm Idris.Core.TT
    Idris.Core.Typecheck Idris.Core.Unify Idris.Core.WHNF
    Idris.Coverage Idris.DSL Idris.DataOpts Idris.DeepSeq
    Idris.Delaborate Idris.Directives Idris.Docs Idris.Docstrings
    Idris.Elab.AsPat Idris.Elab.Clause Idris.Elab.Data
    Idris.Elab.Implementation Idris.Elab.Interface Idris.Elab.Provider
    Idris.Elab.Quasiquote Idris.Elab.Record Idris.Elab.Rewrite
    Idris.Elab.RunElab Idris.Elab.Term Idris.Elab.Transform
    Idris.Elab.Type Idris.Elab.Utils Idris.Elab.Value Idris.ElabDecls
    Idris.Erasure Idris.ErrReverse Idris.Error Idris.Help Idris.IBC
    Idris.IdeMode Idris.IdrisDoc Idris.Imports Idris.Info
    Idris.Info.Show Idris.Inliner Idris.Interactive Idris.Main
    Idris.ModeCommon Idris.Options Idris.Output Idris.Package
    Idris.Package.Common Idris.Package.Parser Idris.Parser
    Idris.Parser.Data Idris.Parser.Expr Idris.Parser.Helpers
    Idris.Parser.Ops Idris.Parser.Stack Idris.PartialEval
    Idris.Primitives Idris.ProofSearch Idris.Prover Idris.Providers
    Idris.REPL Idris.REPL.Browse Idris.REPL.Commands Idris.REPL.Parser
    Idris.Reflection Idris.Termination Idris.Transforms
    Idris.TypeSearch Idris.Unlit Idris.WhoCalls Util.DynamicLinker
    Util.ScreenSize Util.System

hidden-modules:
    Util.Pretty Util.Net Paths_idris Version_idris Tools_idris
    BuildFlags_idris

import-dirs:          /usr/lib/ghc-8.10.4/site-local/idris-1.3.3
library-dirs:         /usr/lib/ghc-8.10.4/site-local/idris-1.3.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/idris
hs-libraries:         HSidris-1.3.3-IUYfrh8doFfLjFwBEieOr1
extra-libraries:      gmp
depends:
    aeson-1.5.6.0-KKLnIH6l1ju5f1LsAaB2FK
    annotated-wl-pprint-0.7.0-HXu68S9Nys8Hg2W61VXV5e
    ansi-terminal-0.11-5i9cd1Vu8V74uNk6uCV4wo
    ansi-wl-pprint-0.6.9-9TMkbhdL43WARfN95smaWt array-0.5.4.0
    async-2.2.3-bRJqoep3gj749cy8sss28 base-4.14.1.0
    base64-bytestring-1.2.0.1-EcdINrHUSFBGuuj0CRlM1c binary-0.8.8.0
    blaze-html-0.9.1.2-3k3fMWFnHX3AFgHeZV1D8E
    blaze-markup-0.8.2.8-4VB51SV8RIBLsZP8H8ryPV bytestring-0.10.12.0
    cheapskate-0.1.1.2-38hG1xdLGo99PaLypIAR56
    code-page-0.2.1-IAY0xrIpRX4LqP27RFJNQj containers-0.6.2.1
    deepseq-1.4.4.0 directory-1.3.6.0 filepath-1.4.2.1
    fingertree-0.1.4.2-56MEZoeCG3UEs5hPNPwbAZ
    fsnotify-0.3.0.1-3hBwj5YO3Q2DnZkL6mMPFI haskeline-0.8.0.1
    ieee754-0.8.0-Fa1NJsiKKLb2eXdrTUzFMJ
    libffi-0.1-9IaAnagAd9mHZyIx4Vvu1D
    megaparsec-9.0.1-CFStyJDCKwJ6JGk3cTsnu0 mtl-2.2.2
    network-3.1.2.1-3J2farqahIBByMpQGhmaOp
    optparse-applicative-0.16.1.0-S52gl7OfafHLRLHRkrUKV
    parser-combinators-1.3.0-DiU4leLN1bk4yjPVc8BdOd pretty-1.1.3.6
    process-1.6.9.0 regex-tdfa-1.3.1.0-JGQEzvFVQF39kClVWuccwj
    safe-0.3.19-AfrHSVViU1189qUhjBUb5b
    split-0.2.3.4-DG0ESn7oq10C3pntDvmtWW
    terminal-size-0.3.2.1-HihNy0RThZk4O1UkYpAxTd text-1.2.4.1
    time-1.9.3 transformers-0.5.6.2
    uniplate-1.6.13-1643d6GufFW70tAtIUb7a unix-2.7.2.2
    unordered-containers-0.2.13.0-Hta4uSSpiP48joPsanuYfX
    utf8-string-1.0.2-7pqBkplor7g1hjwTjVt3SV
    vector-0.12.3.0-GRVR7S4hON84E5j6gLfg6y
    vector-binary-instances-0.2.5.2-JUp9sSpji1b1cCXhptatA4
    zip-archive-0.4.1-4sw3Rb4hAVqIcnfkC41HkW

haddock-interfaces:   /usr/share/doc/idris/html/idris.haddock
haddock-html:         /usr/share/doc/idris/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

